/*-------------------------------------------------------------------------
Function for Converting all channels
Copyright: Maxim Integrated Products
Target: MAX7651
Date: Feb 26, 2004
Author: John Tam

Usage: The function will return 8 conversion results to an array. 

Parameters: p_buffer, pointer to an 8 location array stores the conversion results

Return: Values are returned to the calling function using the function parameters 

/*-------------------------------------------------------------------------
Setup ADC in the MAX7651
--------------------------------------------------------------------------*/

sfr ADCON  = 0xC5;												//Define address of  MAX7651 ADCON
sfr ADDAT1 = 0xC3; 												//Define address of MAX7651 ADDAT1 (8MSBs)
sfr ADDAT0 = 0xC2;												//Define address of MAX7651 ADDAT0 (4LSBs)

void convert_all_channels(int* buffer);

#define NUMBER_OF_CHANNELS 8

void convert_all_channels(int* p_buffer)            			//pointer Buffer to return
{
	int adc_ch;
	int conv_val;

/*-----------------------------------------------
Convert all ADC channels
-----------------------------------------------*/

	for (adc_ch = 0; adc_ch < NUMBER_OF_CHANNELS; adc_ch++)      //for ADC channels 1 to 7
	{

/*-----------------------------------------------	
Start a conversion and wait for it to complete.
-----------------------------------------------*/

	ADCON = adc_ch;												//Start conversion and select channel
	while ((ADCON & 0x80) == 0);								//wait for conversion to complete
	conv_val = (ADDAT0 >> 4) |  (ADDAT1 << 4);					//Format the data in 12 bit format
	
	*(p_buffer+adc_ch) = conv_val;								//Write result back to calling function
	}															//End For
}																//End function convert_all_channels()

 
/*-------------------------------------------------------------------------
Function for Converting a Channel on the MAX7651
Copyright: Maxim Integrated Products
Target: MAX7651
Date: Feb 26, 2004

Usage: The function will convert and return the result of a Channel.
Parameters: adc_ch, Select ADC channel to be converted. 

Channels 0-7 = single ended channel 0-7.
	Channels 8-11 = differential channel pairs {CH0,1}, {CH2,3}, {CH4,5}, {CH6,7}
	Channel 12 = differential reference measurement {REF+,REF-}

Return: Function returns Integer with the conversion result 

Function Declaration: int convert_channel(int adc_ch);
--------------------------------------------------------------------------*/

int convert_channel(int adc_ch)            			
{
	int conv_val;	

	if (ADCON <0 || ADCON >12){									//Check for valid channel
	return (-2048);												//Using -FS for the error code
	}
	
	ADCON = adc_ch;												//Select channel and Start conversion
	while ((ADCON & 0x80) == 0);								//Wait for the conversion to complete

	conv_val = (ADDAT0 >> 4) |  (ADDAT1 << 4);					//Format the data in 12 bit format

	return (conv_val);											//Return result back to calling function
}																//End function convert_channel()
